aboutsummaryrefslogtreecommitdiff
path: root/test
diff options
context:
space:
mode:
authorJoão Barbosa <joao.paulo.barbosa@gmail.com>2017-07-31 22:36:27 +0100
committerJoão Barbosa <joao.paulo.barbosa@gmail.com>2017-10-10 23:46:13 +0100
commit857b32b4b280f13997cf2fa471802ad6a27075fb (patch)
treea96fa620b8dece1098fb812339a79d81e6549f56 /test
parentdf18d29a02ae2804ae8490ea816fe0e88a971e8e (diff)
downloadbitcoin-857b32b4b280f13997cf2fa471802ad6a27075fb.tar.xz
[tests] Add -walletnotify functional test
Diffstat (limited to 'test')
-rwxr-xr-xtest/functional/notifications.py36
1 files changed, 32 insertions, 4 deletions
diff --git a/test/functional/notifications.py b/test/functional/notifications.py
index 80a74c0020..c88972ab91 100755
--- a/test/functional/notifications.py
+++ b/test/functional/notifications.py
@@ -2,23 +2,29 @@
# Copyright (c) 2014-2016 The Bitcoin Core developers
# Distributed under the MIT software license, see the accompanying
# file COPYING or http://www.opensource.org/licenses/mit-license.php.
"""Test the -alertnotify and -blocknotify options."""
import os
from test_framework.test_framework import BitcoinTestFramework
-from test_framework.util import assert_equal, wait_until
+from test_framework.util import assert_equal, wait_until, connect_nodes_bi
class NotificationsTest(BitcoinTestFramework):
def set_test_params(self):
self.num_nodes = 2
+ self.setup_clean_chain = True
def setup_network(self):
self.alert_filename = os.path.join(self.options.tmpdir, "alert.txt")
- self.block_filename = os.path.join(self.options.tmpdir, 'blocks.txt')
+ self.block_filename = os.path.join(self.options.tmpdir, "blocks.txt")
+ self.tx_filename = os.path.join(self.options.tmpdir, "transactions.txt")
+
+ # -alertnotify and -blocknotify on node0, walletnotify on node1
self.extra_args = [["-blockversion=2",
"-alertnotify=echo %%s >> %s" % self.alert_filename,
"-blocknotify=echo %%s >> %s" % self.block_filename],
- ["-blockversion=211"]]
+ ["-blockversion=211",
+ "-rescan",
+ "-walletnotify=echo %%s >> %s" % self.tx_filename]]
super().setup_network()
def run_test(self):
@@ -33,6 +39,28 @@ class NotificationsTest(BitcoinTestFramework):
with open(self.block_filename, 'r') as f:
assert_equal(sorted(blocks), sorted(f.read().splitlines()))
+ self.log.info("test -walletnotify")
+ # wait at most 10 seconds for expected file size before reading the content
+ wait_until(lambda: os.path.isfile(self.tx_filename) and os.stat(self.tx_filename).st_size >= (block_count * 65), timeout=10)
+
+ # file content should equal the generated transaction hashes
+ txids_rpc = list(map(lambda t: t['txid'], self.nodes[1].listtransactions("*", block_count)))
+ with open(self.tx_filename, 'r') as f:
+ assert_equal(sorted(txids_rpc), sorted(f.read().splitlines()))
+ os.remove(self.tx_filename)
+
+ self.log.info("test -walletnotify after rescan")
+ # restart node to rescan to force wallet notifications
+ self.restart_node(1)
+ connect_nodes_bi(self.nodes, 0, 1)
+
+ wait_until(lambda: os.path.isfile(self.tx_filename) and os.stat(self.tx_filename).st_size >= (block_count * 65), timeout=10)
+
+ # file content should equal the generated transaction hashes
+ txids_rpc = list(map(lambda t: t['txid'], self.nodes[1].listtransactions("*", block_count)))
+ with open(self.tx_filename, 'r') as f:
+ assert_equal(sorted(txids_rpc), sorted(f.read().splitlines()))
+
# Mine another 41 up-version blocks. -alertnotify should trigger on the 51st.
self.log.info("test -alertnotify")
self.nodes[1].generate(41)
@@ -2,23 +2,29 @@
# Distributed under the MIT software license, see the accompanying
# file COPYING or http://www.opensource.org/licenses/mit-license.php.
-"""Test the -alertnotify and -blocknotify options."""
+"""Test the -alertnotify, -blocknotify and -walletnotify options."""
import os
from test_framework.test_framework import BitcoinTestFramework